==> layout_paragraphs_limit-1.0.0-rc2.tar.gz: layout_paragraphs_limit/src/EventSubscriber/LayoutParagraphsLimitAllowedTypesSubscriber.php <==
<?php

namespace Drupal\layout_paragraphs_limit\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\layout_paragraphs\Event\LayoutParagraphsAllowedTypesEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class LayoutParagraphsLimitAllowedTypesSubscriber.
 *
 * @package Drupal\layout_paragraphs_limit
 */
class LayoutParagraphsLimitAllowedTypesSubscriber implements EventSubscriberInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * LayoutParagraphsLimitAllowedTypesSubscriber constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      LayoutParagraphsAllowedTypesEvent::EVENT_NAME => 'typeRestrictions',
    ];
  }

  /**
   * Implements typeRestrictions().
   *
   * @param \Drupal\layout_paragraphs\Event\LayoutParagraphsAllowedTypesEvent $event
   *   The event object.
   */
  public function typeRestrictions(LayoutParagraphsAllowedTypesEvent $event) {
    $parent_uuid = $event->getParentUuid();
    $parent = $event->getLayout()->getComponentByUuid($parent_uuid);
    if (!$parent) {
      return;
    }
    $parent_settings = $parent->getSettings();
    $parent_layout = $parent_settings['layout'];

    // Get the disallowed paragraph types for the current layout.
    $disallowed_types = $this->configFactory->get('layout_paragraphs_limit.settings')->get('disallowed_types');

    // Remove the disallowed paragraph types from the allowed types.
    $allowed_types = array_diff_key($event->getTypes(), $disallowed_types[$parent_layout]);

    // Set the updated allowed types.
    $event->setTypes($allowed_types);
  }

}

==> layout_paragraphs_limit-1.0.2.tar.gz: layout_paragraphs_limit/src/EventSubscriber/LayoutParagraphsLimitAllowedTypesSubscriber.php <==
<?php

declare(strict_types = 1);

namespace Drupal\layout_paragraphs_limit\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\layout_paragraphs\Event\LayoutParagraphsAllowedTypesEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Implements LayoutParagraphsLimitAllowedTypesSubscriber class.
 *
 * @package Drupal\layout_paragraphs_limit
 */
class LayoutParagraphsLimitAllowedTypesSubscriber implements EventSubscriberInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * LayoutParagraphsLimitAllowedTypesSubscriber constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      LayoutParagraphsAllowedTypesEvent::EVENT_NAME => 'typeRestrictions',
    ];
  }

  /**
   * Implements typeRestrictions().
   *
   * @param \Drupal\layout_paragraphs\Event\LayoutParagraphsAllowedTypesEvent $event
   *   The event object.
   */
  public function typeRestrictions(LayoutParagraphsAllowedTypesEvent $event) {
    $parent_uuid = $event->getParentUuid();
    $region = $event->getRegion();
    $parent = $event->getLayout()->getComponentByUuid($parent_uuid);
    if (!$parent) {
      return;
    }
    $parent_settings = $parent->getSettings();
    $parent_layout = $parent_settings['layout'];

    // Get the disallowed paragraph types for the current layout.
    $disallowed_types = $this->configFactory->get('layout_paragraphs_limit.settings')->get('disallowed_types');

    // If nothing selected, return.
    if (empty($disallowed_types[$parent_layout][$region]['paragraph_types'])) {
      return;
    }
    if (empty($disallowed_types[$parent_layout][$region]['negate'])) {
      // If negate is empty/false, we exclude the checked types from the list.
      $allowed_types = array_diff_key($event->getTypes(), array_filter($disallowed_types[$parent_layout][$region]['paragraph_types']));
    }
    else {
      // If negate is true, we include only the checked types from the list.
      $allowed_types = array_intersect_key($event->getTypes(), array_filter($disallowed_types[$parent_layout][$region]['paragraph_types']));
    }

    // Set the updated allowed types.
    $event->setTypes($allowed_types);
  }

}
